@@ -1,21 +1,21 @@
 #!/bin/sh
 
 #Fix these valuables for your environment
-VERSION=2.1.1
+VERSION=2.2.0
 #BETA=-beta7
-DISTRO=fc6
-SVNROOT=~/seedit.sourceforge/trunk/
+DISTRO=f8
+SVNROOT=~/seedit/trunk/
 RPMROOT=~/rpm
 
 #Followign values differs from distro
 #For, cos4, ax2, fc6 , they are configured later
 SAMPLE_POLICY_TYPE=fc6
-#AUDITCONF=\\%\\{_sysconfdir\\}\\/audit\\/audit.rules
-AUDITCONF=\\%\\{_sysconfdir\\}\\/audit.rules
-MODULAR=n
-CUSTOMIZABLE_TYPES=n
-PAM_INCLUDE_SUPPORT=n
-AUDIT_OBJ_TYPE_SUPPORT=n
+AUDITCONF=\\%\\{_sysconfdir\\}\\/audit\\/audit.rules
+#AUDITCONF=\\%\\{_sysconfdir\\}\\/audit.rules
+MODULAR=y
+CUSTOMIZABLE_TYPES=y
+PAM_INCLUDE_SUPPORT=y
+AUDIT_OBJ_TYPE_SUPPORT=y
 #If distro have DESKTOP_FILE_UTILS, then y
 HAVE_DESKTOP_FILE_UTILS=y
 
@@ -53,6 +53,7 @@ then
     PAM_INCLUDE_SUPPORT=y
     AUDIT_OBJ_TYPE_SUPPORT=y
 fi
+
 #Fedora Core5 specific
 if [ $DISTRO = "fc5" ]
 then
@@ -65,6 +66,17 @@ then
     AUDIT_OBJ_TYPE_SUPPORT=y
 fi
 
+#Fedora8 
+if [ $DISTRO = "f8" ]
+then
+    HAVE_DESKTOP_FILE_UTILS=y
+    SAMPLE_POLICY_TYPE=f8
+    AUDITCONF=\\%\\{_sysconfdir\\}\\/audit\\/audit.rules
+    MODULAR=y
+    CUSTOMIZABLE_TYPES=y
+    PAM_INCLUDE_SUPPORT=y
+    AUDIT_OBJ_TYPE_SUPPORT=y
+fi
 
 
 mkdir -p archive
