@@ -24,7 +24,7 @@ import string
 import re
 import getopt
 import gettext
-from seedit import getAttr
+from seedit import *
 from stat import *
 gMatchpathcon = "/usr/sbin/matchpathcon -n"
 gAusearch = "/sbin/ausearch"
@@ -322,7 +322,7 @@ def getCandidatePathWithChroot(name, inode,pid, ppid):
 def countPATHEntry(logs):
     i = 0
     for l in logs:        
-        if(string.find(l,"type=PATH")>=0 or string.find(l,"type=AVC_PATH")>=0):
+        if(string.find(l,"name=")>=0 or string.find(l,"path=")>=0):
             i = i+1
     return i
              
@@ -332,37 +332,33 @@ def getPATHEntry(logs,inode):
     if numPATH==0:
         return ""
         
-    for l in logs:        
-        if(string.find(l,"type=PATH")>=0 or string.find(l,"type=AVC_PATH")>=0):
-            m=re.compile("name=\(null\)").search(l)
-            if m:
+    for l in logs:
+        m = re.compile(":.*avc.*:").search(l)
+        if m:
+            continue
+        m = re.compile("path=\S+").search(l)
+        if m:
+            path = string.split(m.group(),"=").pop()                
+            path = string.replace(path,"\"","")
+            return path
+        
+        if (string.find(l,"name=")>0):
+            m = re.compile("name=\S+").search(l)
+            path = string.split(m.group(),"=").pop()
+            path = string.replace(path,"\"","")
+            if path == "(null)":
                 if numPATH>1:
-                    #Search another PATH
                     continue
                 else:
-                    print "Warning name=(null) in PATH:%s" % (l)
+                    return ""
+            if numPATH==1 or inode==-1:
+                return path
+
+            ##Multiple PATH Entry
+            inodeInPATH=getInode(l)
+            if inodeInPATH == inode:
+                return path
             
-            m=re.compile("name=\S+").search(l)
-            if not m:
-                m = re.compile("path=\S+").search(l)
-
-            if m:
-                path = string.split(m.group(),"=").pop()
-                #remove "
-                path = string.replace(path,"\"","")
-                if numPATH==1 or inode==-1:
-                    return path
-
-
-                if string.find(l,"type=AVC_PATH") >=0:
-                    return path
-                
-                ##Multiple PATH Entry
-                inodeInPATH=getInode(l)
-                if inodeInPATH == inode:
-                    return path
-
-                ##else find other PATH entry
     return ""
                 
 def getCWDEntry(logs):
@@ -428,6 +424,7 @@ def guessPathByPATHEntry(lines,index):
         else:
             return realpath
     else:
+        print "#####"+path
         #need to joint CWD
         cwd = getCWDEntry(logs)
         if cwd=="":
@@ -498,11 +495,12 @@ def guessFilePath(rule,lines,index):
         return rule["type"]
 
     path = guessPathByInoDir(line)
-    if path=="":
-   
+    if path=="":   
         path= guessPathByPATHEntry(lines,index)    
-    if path =="":
-        path = guessPathByLocate(line)
+    
+    if gCross == False:
+        if path =="":
+            path = guessPathByLocate(line)
 
         
     updateInoPath(path,line)
@@ -657,6 +655,7 @@ Error: returns None
 def findNameInPath(path,name):
    
     (head,tail)=os.path.split(path)
+
     while head!="/":
         if os.path.basename(head)==name:
             return  head
@@ -665,6 +664,10 @@ def findNameInPath(path,name):
     return None
 
 def genFileAllow(rule,lines,index,domdoc):
+    
+    return __genFileAllow(rule,lines,index,domdoc)
+
+def __genFileAllow(rule,lines,index,domdoc):
     """
     return Dict
     ruletype:   type of SPDL element, this case, allowfile
@@ -676,9 +679,9 @@ def genFileAllow(rule,lines,index,domdoc):
     spRuleList=[]
     spRule = dict()
     line = lines[index]
-
+    
     path = guessFilePath(rule,lines,index)
-  
+
     #for lnk_file class, need special treatment to obtain real fullpath
     if rule["secclass"]=="lnk_file":
         if rule["type"]=="bin_sh_t":
@@ -686,9 +689,10 @@ def genFileAllow(rule,lines,index,domdoc):
             if rule["name"]=="sh":
                 path ="/bin/sh"
         elif not os.path.islink(path):
-            p2 = findNameInPath(path,rule["name"])
-            if p2:
-                path=p2
+            if path:
+                p2 = findNameInPath(path,rule["name"])
+                if p2:
+                    path=p2
         elif os.path.islink(path):
             if "create" in rule["permission"]:
                 ##if creating link, now we have real full path
@@ -750,6 +754,44 @@ def genFileAllow(rule,lines,index,domdoc):
     
     return spRuleList
 
+def __genFileAllowCross(rule,lines,index,domdoc):
+    """
+    return Dict
+    ruletype:   type of SPDL element, this case, allowfile
+    domain:     domain
+    path:       full path
+    name:       only file name not fullpath
+    permission: list of permission     
+    """
+    spRuleList=[]
+    spRule = dict()
+    line = lines[index]
+
+    
+    permList = findFilePermission(domdoc,rule,"allowfile")
+    if not permList:
+        permList = findFilePermission(domdoc,rule,"allowdev")
+    if not permList:
+        return []
+
+    if rule["type"] == "security_t":
+        return None
+
+    spRule["ruletype"]="allowfile"
+    spRule["domain"]=rule["domain"]
+    spRule["type"]=rule["type"]
+    spRule["path"]=rule["name"]
+    if rule.has_key("path"):
+        spRule["path"]=rule["path"]
+    spRule["secclass"]=rule["secclass"]
+
+    spRule["permission"] = permList
+
+    spRuleList.append(spRule)
+    
+    return spRuleList
+
+
 def checkInternal(permissionTag,domdoc):
     """
     This is to avoid to output SPDL rules that is internally used
@@ -861,18 +903,12 @@ def printResult(outList):
     # value List of tuple (filename, line, rule)
     outputStr = dict()
     for l in outList:
-
         (filename, line, rule) = l
-    #    sys.stdout.write(_("#SELinux deny log:\n%s") % line)
-     #   sys.stdout.write(_("#Suggested configuration\n"))
-     #   sys.stdout.write(_("File %s: \n%s\n") %(filename, rule))
         key = filename+rule
 
         if not outputStr.has_key(key):
             outputStr[key]=[]
         outputStr[key].append((filename,line,rule))
-  
-       
 
     for key in outputStr.keys():
         list=outputStr[key]
@@ -1297,22 +1333,24 @@ def getRelatedLog(lines, index):
     i = start -1
     while i>0:
         line = lines[i]
-        if auid == getUniqueAuditId(line):
-            result.insert(0,line)
-        else:
-            break
+        if (string.find(line,"audit") != -1):          
+            if auid == getUniqueAuditId(line):
+                result.insert(0,line)
+            else:
+                break
+        
         i = i-1
     
     l = len(lines)    
     i = start+1
     while i < l:
         line = lines[i]
-        
-        if auid == getUniqueAuditId(line):
-            result.append(line)
-        else:
-            break
-        
+        if (string.find(line,"audit") != -1):
+            if auid == getUniqueAuditId(line):
+                result.append(line)
+            else:
+                break
+    
         i = i+1
 
     return result
@@ -1676,8 +1714,8 @@ def SPDLstr(spRuleList,line):
     for spRule in spRuleList:
         fileName = domainToFileName(spRule["domain"])
         if spRule["domain"]=="unlabeled_t":
-            ruleStr = "#Broken domain, skipped."
-            return ruleStr
+            print "#Warning Broken domain, skipped."
+            continue
         ruleStr=""
         ruletype=spRule["ruletype"]
         if ruletype=="allowfile":
@@ -1709,13 +1747,7 @@ def SPDLstr(spRuleList,line):
 gFileClass = ["dir","file","lnk_file","sock_file", "fifo_file","chr_file","blk_file" ]
 
 #Path to simplified policy
-gSPPath="/etc/seedit/policy/all.sp"
 #
-gGeneratedPolicy="/usr/share/seedit/sepolicy/generated.conf"
-#Path to converter.conf
-gConverterConf="/usr/share/seedit/base_policy/converter.conf"
-#Path to spdl_spec.xml
-gSpecXML="/usr/share/seedit/base_policy/spdl_spec.xml"
 #labels defined by allow exclusive rule
 gExcLabelList=getExcLabelList(gGeneratedPolicy)
 
@@ -1724,7 +1756,7 @@ gExcLabelList=getExcLabelList(gGeneratedPolicy)
 gFsLabelList=getFsLabelList(gConverterConf)
 #list of domain defined in SPDL
 #Note that suffix of gRoleList is "_t" not "_r"
-( gDomainList, gRoleList ) = getDomainList(gSPPath)
+( gDomainList, gRoleList ) = getDomainList(gAllsp)
 
 gRootNodeName="spdl"
 #list of unlabeled types
@@ -1744,3 +1776,4 @@ gVerboseFlag =False
 gRestoreconFlag = False
 
 gOutput="/etc/selinux/seedit/src/simplified_policy"
+
